==============================================
Sound archives of the CNRS - Musée de l'Homme
==============================================

The establishment of the `CREM <http://www.crem-cnrs.fr>`_’s audio archives is the result of a long history of scientific research on music. Since the birth of ethnomusicology (then "comparative musicology"), which coincided with the invention of the first recorders in the late nineteenth century, recording music materials and their classification and preservation are central in our knowledge of the musical Man.

.. image:: home_img.jpg
    :align: left

With the foundation of the Sound Archive at the Musée d’Ethnographie du Trocadéro by André Schaeffner in 1932 (which became the Sound Archive of the Musée de l’Homme in 1937) and the creation in 1967 of "Laboratoire d’Analyse sonore" on Gilbert Rouget initiative and the creation of a research team from the `CNRS <http://www.cnrs.fr/>`_ (Scientific Research National Center in France) in 1968, both at the `Musée de l’Homme <http://www.museedelhomme.fr/>`_, the conservation of this vast archives collection was more closely related to research : it is powered by the fieldworks of researchers on all continents; collections can serve for research, diachronic and synchronic comparisons, the preparation of new fieldworks and the training of Ph.D students. In 1985, the `CNRS <http://www.cnrs.fr/>`_ and the `Musée National d'Histoire Naturelle <http://www.mnhn.fr/>`_ (National Museum of Natural History) decided to join efforts to preserve this vast archives, therefore called "Sound Archives of CNRS - Musée de l'Homme". A small portion of these archives has been published in 78s (Vox Africa, etc ...), 33 rpm discs and CD (Chant du Monde, Harmonia Mundi). Currently, analogic media are being digitalized with the assistance of the Ministry of Culture and National Library of France. With the installation of the `Center for Research in Ethnomusicology <http://www.crem-cnrs.fr>`_ (CREM, Department of Ethnology and Comparative Sociology, CNRS UMR 7186) at the University of Paris Ouest-Nanterre in 2009, and the opening of the `Telemeta <http://telemeta.org>`_ platform in 2010, this collection sound archives from the era of the Internet.

The archives of CREM, the most important in Europe, are distinguished by their wealth:

 * Nearly 3,500 hours of recordings of unpublished field.
 * Approximately 3700 hours of material published (more than 5000 discs, many of which are very rare).

The collaborative platform `Telemeta <http://telemeta.org>`_ aims to make these archives available to researchers and to the extent possible, the public, in compliance with the intellectual and moral rights of musicians and collectors. Developed with the support of the program `TGE-Adonis <http://www.tge-adonis.fr/>`_ of the `CNRS <http://www.cnrs.fr/>`_, allows researchers to exchange data online with communities producing their music in their home countries, including through collaborative tools like markers , spaces, comments, etc...

This site is managed by the `CREM <http://www.crem-cnrs.fr>`_. All collaborations are welcome to enrich and enhance this precious musical heritage common to all humanity. Currently, a thousand hours is searchable by code or `access on site and CREM (Université Paris Ouest - Nanterre - La Défense, Building C, Ground Floor, Room 20) <http://goo.gl/maps/ZgHg>`_, and the Central Library Muséum National d'Histoire Naturelle, and the Bibliothèque François Mitterand (garden).

|
